@@ -161,52 +161,55 @@ static void cleanup_rewrite_sender(CLEANUP_STATE *state, HEADER_OPTS *hdr_opts,
     TOK822 *tree;
     TOK822 **addr_list;
     TOK822 **tpp;
-    int     did_rewrite = 0;
 
     if (msg_verbose)
 	msg_info("rewrite_sender: %s", hdr_opts->name);
 
     /*
-     * Parse the header line, rewrite each address found, and regenerate the
-     * header line. Finally, pipe the result through the header line folding
-     * routine.
+     * Parse the header line, rewrite each address found, save copies of
+     * sender addresses, and regenerate the header line. Finally, pipe the
+     * result through the header line folding routine.
      */
     tree = tok822_parse_limit(vstring_str(header_buf)
 			      + strlen(hdr_opts->name) + 1,
 			      var_token_limit);
     addr_list = tok822_grep(tree, TOK822_ADDR);
     for (tpp = addr_list; *tpp; tpp++) {
-	did_rewrite |= cleanup_rewrite_tree(state->hdr_rewrite_context, *tpp);
+	cleanup_rewrite_tree(*tpp);
 	if (state->flags & CLEANUP_FLAG_MAP_OK) {
 	    if (cleanup_send_canon_maps
 		&& (cleanup_send_canon_flags & CLEANUP_CANON_FLAG_HDR_FROM))
-		did_rewrite |=
-		    cleanup_map11_tree(state, *tpp, cleanup_send_canon_maps,
+		cleanup_map11_tree(state, *tpp, cleanup_send_canon_maps,
 				cleanup_ext_prop_mask & EXT_PROP_CANONICAL);
 	    if (cleanup_comm_canon_maps
 		&& (cleanup_comm_canon_flags & CLEANUP_CANON_FLAG_HDR_FROM))
-		did_rewrite |=
-		    cleanup_map11_tree(state, *tpp, cleanup_comm_canon_maps,
+		cleanup_map11_tree(state, *tpp, cleanup_comm_canon_maps,
 				cleanup_ext_prop_mask & EXT_PROP_CANONICAL);
 	    if (cleanup_masq_domains
 		&& (cleanup_masq_flags & CLEANUP_MASQ_FLAG_HDR_FROM))
-		did_rewrite |=
-		    cleanup_masquerade_tree(*tpp, cleanup_masq_domains);
+		cleanup_masquerade_tree(*tpp, cleanup_masq_domains);
 	}
+	if (hdr_opts->type == HDR_FROM && state->from == 0)
+	    state->from = cleanup_extract_internal(header_buf, *tpp);
+	if (hdr_opts->type == HDR_RESENT_FROM && state->resent_from == 0)
+	    state->resent_from =
+		cleanup_extract_internal(header_buf, *tpp);
+#if 0
+	if (hdr_opts->type == HDR_RETURN_RECEIPT_TO && !state->return_receipt)
+	    state->return_receipt =
+		cleanup_extract_internal(header_buf, *tpp);
+#endif
+	if (var_enable_errors_to)
+	    if (hdr_opts->type == HDR_ERRORS_TO && !state->errors_to)
+		state->errors_to =
+		    cleanup_extract_internal(header_buf, *tpp);
     }
-    if (did_rewrite) {
-	vstring_truncate(header_buf, strlen(hdr_opts->name));
-	vstring_strcat(header_buf, ": ");
-	tok822_externalize(header_buf, tree, TOK822_STR_HEAD);
-    }
+    vstring_sprintf(header_buf, "%s: ", hdr_opts->name);
+    tok822_externalize(header_buf, tree, TOK822_STR_HEAD);
     myfree((char *) addr_list);
     tok822_free_tree(tree);
-    if ((hdr_opts->flags & HDR_OPT_DROP) == 0) {
-	if (did_rewrite)
-	    cleanup_fold_header(state, header_buf);
-	else
-	    cleanup_out_header(state, header_buf);
-    }
+    if ((hdr_opts->flags & HDR_OPT_DROP) == 0)
+	cleanup_fold_header(state, header_buf);
 }
 
 /* cleanup_rewrite_recip - recipient address rewriting */
@@ -217,52 +220,41 @@ static void cleanup_rewrite_recip(CLEANUP_STATE *state, HEADER_OPTS *hdr_opts,
     TOK822 *tree;
     TOK822 **addr_list;
     TOK822 **tpp;
-    int     did_rewrite = 0;
 
     if (msg_verbose)
 	msg_info("rewrite_recip: %s", hdr_opts->name);
 
     /*
-     * Parse the header line, rewrite each address found, and regenerate the
-     * header line. Finally, pipe the result through the header line folding
-     * routine.
+     * Parse the header line, rewrite each address found, save copies of
+     * recipient addresses, and regenerate the header line. Finally, pipe the
+     * result through the header line folding routine.
      */
     tree = tok822_parse_limit(vstring_str(header_buf)
 			      + strlen(hdr_opts->name) + 1,
 			      var_token_limit);
     addr_list = tok822_grep(tree, TOK822_ADDR);
     for (tpp = addr_list; *tpp; tpp++) {
-	did_rewrite |= cleanup_rewrite_tree(state->hdr_rewrite_context, *tpp);
+	cleanup_rewrite_tree(*tpp);
 	if (state->flags & CLEANUP_FLAG_MAP_OK) {
 	    if (cleanup_rcpt_canon_maps
 		&& (cleanup_rcpt_canon_flags & CLEANUP_CANON_FLAG_HDR_RCPT))
-		did_rewrite |=
-		    cleanup_map11_tree(state, *tpp, cleanup_rcpt_canon_maps,
+		cleanup_map11_tree(state, *tpp, cleanup_rcpt_canon_maps,
 				cleanup_ext_prop_mask & EXT_PROP_CANONICAL);
 	    if (cleanup_comm_canon_maps
 		&& (cleanup_comm_canon_flags & CLEANUP_CANON_FLAG_HDR_RCPT))
-		did_rewrite |=
-		    cleanup_map11_tree(state, *tpp, cleanup_comm_canon_maps,
+		cleanup_map11_tree(state, *tpp, cleanup_comm_canon_maps,
 				cleanup_ext_prop_mask & EXT_PROP_CANONICAL);
 	    if (cleanup_masq_domains
 		&& (cleanup_masq_flags & CLEANUP_MASQ_FLAG_HDR_RCPT))
-		did_rewrite |=
-		    cleanup_masquerade_tree(*tpp, cleanup_masq_domains);
+		cleanup_masquerade_tree(*tpp, cleanup_masq_domains);
 	}
     }
-    if (did_rewrite) {
-	vstring_truncate(header_buf, strlen(hdr_opts->name));
-	vstring_strcat(header_buf, ": ");
-	tok822_externalize(header_buf, tree, TOK822_STR_HEAD);
-    }
+    vstring_sprintf(header_buf, "%s: ", hdr_opts->name);
+    tok822_externalize(header_buf, tree, TOK822_STR_HEAD);
     myfree((char *) addr_list);
     tok822_free_tree(tree);
-    if ((hdr_opts->flags & HDR_OPT_DROP) == 0) {
-	if (did_rewrite)
-	    cleanup_fold_header(state, header_buf);
-	else
-	    cleanup_out_header(state, header_buf);
-    }
+    if ((hdr_opts->flags & HDR_OPT_DROP) == 0)
+	cleanup_fold_header(state, header_buf);
 }
 
 /* cleanup_act_log - log action with context */
@@ -295,9 +287,8 @@ static void cleanup_act_log(CLEANUP_STATE *state,
 
 /* cleanup_act - act upon a header/body match */
 
-static const char *cleanup_act(CLEANUP_STATE *state, char *context,
-			               const char *buf, const char *value,
-			               const char *map_class)
+static int cleanup_act(CLEANUP_STATE *state, char *context, const char *buf,
+		               const char *value, const char *map_class)
 {
     const char *optional_text = value + strcspn(value, " \t");
     int     command_len = optional_text - value;
@@ -306,6 +297,7 @@ static const char *cleanup_act(CLEANUP_STATE *state, char *context,
 	optional_text++;
 
 #define STREQUAL(x,y,l) (strncasecmp((x), (y), (l)) == 0 && (y)[l] == 0)
+#define CLEANUP_ACT_KEEP 1
 #define CLEANUP_ACT_DROP 0
 
     if (STREQUAL(value, "REJECT", command_len)) {
@@ -315,18 +307,17 @@ static const char *cleanup_act(CLEANUP_STATE *state, char *context,
 	state->errs |= CLEANUP_STAT_CONT;
 	state->flags &= ~CLEANUP_FLAG_FILTER;
 	cleanup_act_log(state, "reject", context, buf, state->reason);
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "WARN", command_len)) {
 	cleanup_act_log(state, "warning", context, buf, optional_text);
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "FILTER", command_len)) {
 	if (*optional_text == 0) {
 	    msg_warn("missing FILTER command argument in %s map", map_class);
 	} else if (strchr(optional_text, ':') == 0) {
-	    msg_warn("bad FILTER command %s in %s -- "
-		     "need transport:destination",
+	    msg_warn("bad FILTER command %s in %s, need transport:destination",
 		     optional_text, map_class);
 	} else {
 	    if (state->filter)
@@ -334,52 +325,36 @@ static const char *cleanup_act(CLEANUP_STATE *state, char *context,
 	    state->filter = mystrdup(optional_text);
 	    cleanup_act_log(state, "filter", context, buf, optional_text);
 	}
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "DISCARD", command_len)) {
 	cleanup_act_log(state, "discard", context, buf, optional_text);
 	state->flags |= CLEANUP_FLAG_DISCARD;
 	state->flags &= ~CLEANUP_FLAG_FILTER;
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "HOLD", command_len)) {
 	cleanup_act_log(state, "hold", context, buf, optional_text);
 	state->flags |= CLEANUP_FLAG_HOLD;
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "PREPEND", command_len)) {
 	if (*optional_text == 0) {
 	    msg_warn("PREPEND action without text in %s map", map_class);
 	} else if (strcmp(context, CLEANUP_ACT_CTXT_HEADER) == 0
 		   && !is_header(optional_text)) {
-	    msg_warn("bad PREPEND header text \"%s\" in %s map -- "
+	    msg_warn("bad PREPEND header text \"%s\" in %s map, "
 		     "need \"headername: headervalue\"",
 		     optional_text, map_class);
 	} else {
 	    cleanup_act_log(state, "prepend", context, buf, optional_text);
 	    cleanup_out_string(state, REC_TYPE_NORM, optional_text);
 	}
-	return (buf);
-    }
-    if (STREQUAL(value, "REPLACE", command_len)) {
-	if (*optional_text == 0) {
-	    msg_warn("REPLACE action without text in %s map", map_class);
-	    return (buf);
-	} else if (strcmp(context, CLEANUP_ACT_CTXT_HEADER) == 0
-		   && !is_header(optional_text)) {
-	    msg_warn("bad REPLACE header text \"%s\" in %s map -- "
-		     "need \"headername: headervalue\"",
-		     optional_text, map_class);
-	    return (buf);
-	} else {
-	    cleanup_act_log(state, "replace", context, buf, optional_text);
-	    return (mystrdup(optional_text));
-	}
+	return (CLEANUP_ACT_KEEP);
     }
     if (STREQUAL(value, "REDIRECT", command_len)) {
 	if (strchr(optional_text, '@') == 0) {
-	    msg_warn("bad REDIRECT target \"%s\" in %s map -- "
-		     "need user@domain",
+	    msg_warn("bad REDIRECT target \"%s\" in %s map, need user@domain",
 		     optional_text, map_class);
 	} else {
 	    if (state->redirect)
@@ -388,7 +363,7 @@ static const char *cleanup_act(CLEANUP_STATE *state, char *context,
 	    cleanup_act_log(state, "redirect", context, buf, optional_text);
 	    state->flags &= ~CLEANUP_FLAG_FILTER;
 	}
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
     }
     /* Allow and ignore optional text after the action. */
 
@@ -396,13 +371,13 @@ static const char *cleanup_act(CLEANUP_STATE *state, char *context,
 	return (CLEANUP_ACT_DROP);
 
     if (STREQUAL(value, "DUNNO", command_len))	/* preferred */
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
 
     if (STREQUAL(value, "OK", command_len))	/* compat */
-	return (buf);
+	return (CLEANUP_ACT_KEEP);
 
     msg_warn("unknown command in %s map: %s", map_class, value);
-    return (buf);
+    return (CLEANUP_ACT_KEEP);
 }
 
 /* cleanup_header_callback - process one complete header line */
@@ -451,17 +426,10 @@ static void cleanup_header_callback(void *context, int header_class,
 	const char *value;
 
 	if ((value = maps_find(checks, header, 0)) != 0) {
-	    const char *result;
-
-	    if ((result = cleanup_act(state, CLEANUP_ACT_CTXT_HEADER,
-				      header, value, map_class))
-		== CLEANUP_ACT_DROP) {
+	    if (cleanup_act(state, CLEANUP_ACT_CTXT_HEADER,
+			    header, value, map_class)
+		== CLEANUP_ACT_DROP)
 		return;
-	    } else if (result != header) {
-		vstring_strcpy(header_buf, result);
-		hdr_opts = header_opts_find(result);
-		myfree((char *) result);
-	    }
 	}
     }
 
@@ -543,11 +511,9 @@ static void cleanup_header_callback(void *context, int header_class,
 	if (CLEANUP_OUT_OK(state)) {
 	    if (hdr_opts->flags & HDR_OPT_RR)
 		state->resent = "Resent-";
-	    if ((hdr_opts->flags & HDR_OPT_SENDER)
-		&& state->hdr_rewrite_context) {
+	    if (hdr_opts->flags & HDR_OPT_SENDER) {
 		cleanup_rewrite_sender(state, hdr_opts, header_buf);
-	    } else if ((hdr_opts->flags & HDR_OPT_RECIP)
-		       && state->hdr_rewrite_context) {
+	    } else if (hdr_opts->flags & HDR_OPT_RECIP) {
 		cleanup_rewrite_recip(state, hdr_opts, header_buf);
 	    } else if ((hdr_opts->flags & HDR_OPT_DROP) == 0) {
 		cleanup_out_header(state, header_buf);
@@ -564,7 +530,6 @@ static void cleanup_header_done_callback(void *context)
     char    time_stamp[1024];		/* XXX locale dependent? */
     struct tm *tp;
     TOK822 *token;
-    time_t  tv;
 
     /*
      * Add a missing (Resent-)Message-Id: header. The message ID gives the
@@ -574,17 +539,10 @@ static void cleanup_header_done_callback(void *context)
      * 
      * XXX It is the queue ID non-inode bits that prevent messages from getting
      * the same Message-Id within the same second.
-     * 
-     * XXX An arbitrary amount of time may pass between the start of the mail
-     * transaction and the creation of a queue file. Since we guarantee queue
-     * ID uniqueness only within a second, we must ensure that the time in
-     * the message ID matches the queue ID creation time, as long as we use
-     * the queue ID in the message ID.
      */
     if ((state->headers_seen & (1 << (state->resent[0] ?
 			   HDR_RESENT_MESSAGE_ID : HDR_MESSAGE_ID))) == 0) {
-	tv = state->handle->ctime.tv_sec;
-	tp = gmtime(&tv);
+	tp = gmtime(&state->time);
 	strftime(time_stamp, sizeof(time_stamp), "%Y%m%d%H%M%S", tp);
 	cleanup_out_format(state, REC_TYPE_NORM, "%sMessage-Id: <%s.%s@%s>",
 		state->resent, time_stamp, state->queue_id, var_myhostname);
@@ -675,17 +633,10 @@ static void cleanup_body_callback(void *context, int type,
 	const char *value;
 
 	if ((value = maps_find(cleanup_body_checks, buf, 0)) != 0) {
-	    const char *result;
-
-	    if ((result = cleanup_act(state, CLEANUP_ACT_CTXT_BODY,
-				      buf, value, VAR_BODY_CHECKS))
-		== CLEANUP_ACT_DROP) {
+	    if (cleanup_act(state, CLEANUP_ACT_CTXT_BODY,
+			    buf, value, VAR_BODY_CHECKS)
+		== CLEANUP_ACT_DROP)
 		return;
-	    } else if (result != buf) {
-		cleanup_out(state, type, result, strlen(result));
-		myfree((char *) result);
-		return;
-	    }
 	}
     }
     cleanup_out(state, type, buf, len);
