@@ -131,7 +131,6 @@
 #include <verp_sender.h>
 #include <mail_proto.h>
 #include <qmgr_user.h>
-#include <split_addr.h>
 
 /* Client stubs. */
 
@@ -186,7 +185,6 @@ static QMGR_MESSAGE *qmgr_message_create(const char *queue_name,
     message->sasl_method = 0;
     message->sasl_username = 0;
     message->sasl_sender = 0;
-    message->rewrite_context = 0;
     qmgr_rcpt_list_init(&message->rcpt_list);
     message->rcpt_count = 0;
     message->rcpt_limit = var_qmgr_msg_rcpt_limit;
@@ -234,7 +232,8 @@ static int qmgr_message_open(QMGR_MESSAGE *message)
 static void qmgr_message_oldstyle_scan(QMGR_MESSAGE *message)
 {
     VSTRING *buf;
-    long    orig_offset, extra_offset;
+    long    orig_offset,
+            extra_offset;
     int     rec_type;
     char   *start;
 
@@ -569,28 +568,21 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 		    message->sasl_method = mystrdup(value);
 		else
 		    msg_warn("%s: ignoring multiple %s attribute: %s",
-			   message->queue_id, MAIL_ATTR_SASL_METHOD, value);
+			message->queue_id, MAIL_ATTR_SASL_METHOD, value);
 	    }
 	    if (strcmp(name, MAIL_ATTR_SASL_USERNAME) == 0) {
 		if (message->sasl_username == 0)
 		    message->sasl_username = mystrdup(value);
 		else
 		    msg_warn("%s: ignoring multiple %s attribute: %s",
-			 message->queue_id, MAIL_ATTR_SASL_USERNAME, value);
+			message->queue_id, MAIL_ATTR_SASL_USERNAME, value);
 	    }
 	    if (strcmp(name, MAIL_ATTR_SASL_SENDER) == 0) {
 		if (message->sasl_sender == 0)
 		    message->sasl_sender = mystrdup(value);
 		else
 		    msg_warn("%s: ignoring multiple %s attribute: %s",
-			   message->queue_id, MAIL_ATTR_SASL_SENDER, value);
-	    }
-	    if (strcmp(name, MAIL_ATTR_RWR_CONTEXT) == 0) {
-		if (message->rewrite_context == 0)
-		    message->rewrite_context = mystrdup(value);
-		else
-		    msg_warn("%s: ignoring multiple %s attribute: %s",
-			   message->queue_id, MAIL_ATTR_RWR_CONTEXT, value);
+			message->queue_id, MAIL_ATTR_SASL_SENDER, value);
 	    }
 	    /* Optional tracing flags. */
 	    else if (strcmp(name, MAIL_ATTR_TRACE_FLAGS) == 0) {
@@ -671,8 +663,6 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 	message->sasl_username = mystrdup("");
     if (message->sasl_sender == 0)
 	message->sasl_sender = mystrdup("");
-    if (message->rewrite_context == 0)
-	message->rewrite_context = mystrdup(MAIL_ATTR_RWR_LOCAL);
 
     /*
      * Clean up.
@@ -885,14 +875,8 @@ static void qmgr_message_resolve(QMGR_MESSAGE *message)
 
 	/*
 	 * Content filtering overrides the address resolver.
-	 * 
-	 * XXX Bypass content_filter inspection for user-generated probes
-	 * (sendmail -bv). MTA-generated probes never have the "please filter
-	 * me" bits turned on, but we handle them here anyway for the sake of
-	 * future proofing.
 	 */
-	else if (message->filter_xport
-		 && (message->tflags & DEL_REQ_TRACE_ONLY_MASK) == 0) {
+	else if (message->filter_xport) {
 	    vstring_strcpy(reply.transport, message->filter_xport);
 	    if ((nexthop = split_at(STR(reply.transport), ':')) == 0
 		|| *nexthop == 0)
@@ -1230,8 +1214,6 @@ void    qmgr_message_free(QMGR_MESSAGE *message)
 	myfree(message->sasl_username);
     if (message->sasl_sender)
 	myfree(message->sasl_sender);
-    if (message->rewrite_context)
-	myfree(message->rewrite_context);
     qmgr_rcpt_list_free(&message->rcpt_list);
     qmgr_message_count--;
     myfree((char *) message);
@@ -1281,17 +1263,10 @@ QMGR_MESSAGE *qmgr_message_alloc(const char *queue_name, const char *queue_id,
 	 * queue file and *before* resolving new recipients. Since all those
 	 * operations are encapsulated so nicely by this routine, the defer
 	 * log reset has to be done here as well.
-	 * 
-	 * Likewise remove a trace file with results from address verification,
-	 * "what if" testing, or verbose delivery.
 	 */
 	if (mail_queue_remove(MAIL_QUEUE_DEFER, queue_id) && errno != ENOENT)
 	    msg_fatal("%s: %s: remove %s %s: %m", myname,
 		      queue_id, MAIL_QUEUE_DEFER, queue_id);
-	if (message->tflags != 0
-	&& mail_queue_remove(MAIL_QUEUE_TRACE, queue_id) && errno != ENOENT)
-	    msg_fatal("%s: %s: remove %s %s: %m", myname,
-		      queue_id, MAIL_QUEUE_TRACE, queue_id);
 	qmgr_message_sort(message);
 	qmgr_message_resolve(message);
 	qmgr_message_sort(message);
