@@ -2,44 +2,44 @@
 /* NAME
 /*	scache 8
 /* SUMMARY
-/*	Postfix shared connection cache server
+/*	Postfix session cache server
 /* SYNOPSIS
 /*	\fBscache\fR [generic Postfix daemon options]
 /* DESCRIPTION
-/*	The \fBscache\fR(8) server maintains a shared multi-connection
+/*	The \fBscache\fR server maintains a shared multi-session
 /*	cache. This information can be used by, for example, Postfix
 /*	SMTP clients or other Postfix delivery agents.
 /*
-/*	The connection cache is organized into logical destination
-/*	names, physical endpoint names, and connections.
+/*	The session cache is organized into logical destination
+/*	names, physical endpoint names, and sessions.
 /*
 /*	As a specific example, logical SMTP destinations specify
 /*	(transport, domain, port), and physical SMTP endpoints
-/*	specify (transport, IP address, port).  An SMTP connection
+/*	specify (transport, IP address, port).  An SMTP session
 /*	may be saved after a successful mail transaction.
 /*
 /*	In the general case, one logical destination may refer to
 /*	zero or more physical endpoints, one physical endpoint may
 /*	be referenced by zero or more logical destinations, and
-/*	one endpoint may refer to zero or more connections.
+/*	one endpoint may refer to zero or more sessions.
 /*
 /*	The exact syntax of a logical destination or endpoint name
-/*	is application dependent; the \fBscache\fR(8) server does
-/*	not care.  A connection is stored as a file descriptor together
+/*	is application dependent; the \fBscache\fR service does
+/*	not care.  A session is stored as a file descriptor together
 /*	with application-dependent information that is needed to
-/*	re-activate a connection object. Again, the \fBscache\fR(8)
-/*	server is completely unaware of the details of that
+/*	re-activate a session object. Again, the \fBscache\fR
+/*	service is completely unaware about the details of that
 /*	information.
 /*
 /*	All information is stored with a finite time to live (ttl).
-/*	The connection cache daemon terminates when no client is
+/*	The session cache daemon terminates when no client is
 /*	connected for \fBmax_idle\fR time units.
 /*
 /*	This server implements the following requests:
 /* .IP "\fBsave_endp\fI ttl endpoint endpoint_properties file_descriptor\fR"
-/*	Save the specified file descriptor and connection property data
+/*	Save the specified file descriptor and session property data
 /*	under the specified endpoint name. The endpoint properties
-/*	are used by the client to re-activate a passivated connection
+/*	are used by the client to re-activate a passivated session
 /*	object.
 /* .IP "\fBfind_endp\fI endpoint\fR"
 /*	Look up cached properties and a cached file descriptor for the
@@ -47,8 +47,8 @@
 /* .IP "\fBsave_dest\fI ttl destination destination_properties endpoint\fR"
 /*	Save the binding between a logical destination and an
 /*	endpoint under the destination name, together with destination
-/*	specific connection properties. The destination properties
-/*	are used by the client to re-activate a passivated connection
+/*	specific session properties. The destination properties
+/*	are used by the client to re-activate a passivated session
 /*	object.
 /* .IP "\fBfind_dest\fI destination\fR"
 /*	Look up cached destination properties, cached endpoint properties,
@@ -56,38 +56,37 @@
 /* SECURITY
 /* .ad
 /* .fi
-/*	The \fBscache\fR(8) server is not security-sensitive. It does not
+/*	The session cache server is not security-sensitive. It does not
 /*	talk to the network, and it does not talk to local users.
-/*	The \fBscache\fR(8) server can run chrooted at fixed low privilege.
+/*	The scache server can run chrooted at fixed low privilege.
 /*
-/*	The \fBscache\fR(8) server is not a trusted process. It must
+/*	The session cache server is not a trusted process. It must
 /*	not be used to store information that is security sensitive.
 /* DIAGNOSTICS
 /*	Problems and transactions are logged to \fBsyslogd\fR(8).
 /* BUGS
-/*	The session cache cannot be shared among multiple machines.
+/*	Sessions cannot be cached across multiple machines.
 /*
-/*	When a connection expires from the cache, it is closed without
-/*	the appropriate protocol specific handshake.
+/*      When a session expires from the cache it is closed without
+/*	protocol specific handshake.
 /* CONFIGURATION PARAMETERS
 /* .ad
 /* .fi
-/*	Changes to \fBmain.cf\fR are picked up automatically as \fBscache\fR(8)
+/*	Changes to \fBmain.cf\fR are picked up automatically as scache(8)
 /*	processes run for only a limited amount of time. Use the command
 /*	"\fBpostfix reload\fR" to speed up a change.
 /*
 /*	The text below provides only a parameter summary. See
-/*	\fBpostconf\fR(5) for more details including examples.
+/*	postconf(5) for more details including examples.
 /* RESOURCE CONTROLS
 /* .ad
 /* .fi
-/* .IP "\fBconnection_cache_ttl_limit (2s)\fR"
-/*	The maximal time-to-live value that the \fBscache\fR(8) connection
-/*	cache server
+/* .IP "\fBsession_cache_ttl_limit (2s)\fR"
+/*	The maximal time-to-live value that the session cache server
 /*	allows.
-/* .IP "\fBconnection_cache_status_update_time (600s)\fR"
-/*	How frequently the \fBscache\fR(8) server logs usage statistics with
-/*	connection cache hit and miss rates for logical destinations and for
+/* .IP "\fBsession_cache_status_update_time (600s)\fR"
+/*	How frequently the scache(8) server logs usage statistics with
+/*	session cache hit and miss rates for logical destinations and for
 /*	physical endpoints.
 /* MISCELLANEOUS CONTROLS
 /* .ad
@@ -118,14 +117,6 @@
 /*	postconf(5), configuration parameters
 /*	master(8), process manager
 /*	syslogd(8), system logging
-/* README FILES
-/* .ad
-/* .fi
-/*	Use "\fBpostconf readme_directory\fR" or
-/*	"\fBpostconf html_directory\fR" to locate this information.
-/* .na
-/* .nf
-/*	CONNECTION_CACHE_README, Postfix connection cache
 /* LICENSE
 /* .ad
 /* .fi
@@ -240,18 +231,18 @@ static void scache_save_endp_service(VSTREAM *client_stream)
 	       ||
 #endif
 	       (fd = LOCAL_RECV_FD(vstream_fileno(client_stream))) < 0) {
-	msg_warn("%s: unable to receive file descriptor: %m", myname);
-	(void) attr_print(client_stream, ATTR_FLAG_NONE,
-			  ATTR_TYPE_NUM, MAIL_ATTR_STATUS, SCACHE_STAT_FAIL,
-			  ATTR_TYPE_END);
+	msg_warn("%s: unable to receive file descriptor", myname);
+	attr_print(client_stream, ATTR_FLAG_NONE,
+		   ATTR_TYPE_NUM, MAIL_ATTR_STATUS, SCACHE_STAT_FAIL,
+		   ATTR_TYPE_END);
 	return;
     } else {
 	scache_save_endp(scache,
 			 ttl > var_scache_ttl_lim ? var_scache_ttl_lim : ttl,
 			 STR(scache_endp_label), STR(scache_endp_prop), fd);
-	(void) attr_print(client_stream, ATTR_FLAG_NONE,
-			  ATTR_TYPE_NUM, MAIL_ATTR_STATUS, SCACHE_STAT_OK,
-			  ATTR_TYPE_END);
+	attr_print(client_stream, ATTR_FLAG_NONE,
+		   ATTR_TYPE_NUM, MAIL_ATTR_STATUS, SCACHE_STAT_OK,
+		   ATTR_TYPE_END);
 	scache_size(scache, &size);
 	if (size.endp_count > scache_endp_count)
 	    scache_endp_count = size.endp_count;
@@ -261,7 +252,7 @@ static void scache_save_endp_service(VSTREAM *client_stream)
     }
 }
 
-/* scache_find_endp_service - protocol to find connection for endpoint */
+/* scache_find_endp_service - protocol to find session for endpoint */
 
 static void scache_find_endp_service(VSTREAM *client_stream)
 {
@@ -297,13 +288,7 @@ static void scache_find_endp_service(VSTREAM *client_stream)
 			 ATTR_TYPE_STR, MAIL_ATTR_DUMMY, scache_dummy,
 			 ATTR_TYPE_END) != 1
 #endif
-	    || LOCAL_SEND_FD(vstream_fileno(client_stream), fd) < 0
-#ifdef MUST_READ_AFTER_SENDING_FD
-	    || attr_scan(client_stream, ATTR_FLAG_STRICT,
-			 ATTR_TYPE_STR, MAIL_ATTR_DUMMY, scache_dummy,
-			 ATTR_TYPE_END) != 1
-#endif
-	    )
+	    || LOCAL_SEND_FD(vstream_fileno(client_stream), fd) < 0)
 	    msg_warn("%s: cannot send file descriptor: %m", myname);
 	if (close(fd) < 0)
 	    msg_warn("close(%d): %m", fd);
@@ -350,7 +335,7 @@ static void scache_save_dest_service(VSTREAM *client_stream)
     }
 }
 
-/* scache_find_dest_service - protocol to find connection for destination */
+/* scache_find_dest_service - protocol to find session for destination */
 
 static void scache_find_dest_service(VSTREAM *client_stream)
 {
@@ -390,13 +375,7 @@ static void scache_find_dest_service(VSTREAM *client_stream)
 			 ATTR_TYPE_STR, MAIL_ATTR_DUMMY, scache_dummy,
 			 ATTR_TYPE_END) != 1
 #endif
-	    || LOCAL_SEND_FD(vstream_fileno(client_stream), fd) < 0
-#ifdef MUST_READ_AFTER_SENDING_FD
-	    || attr_scan(client_stream, ATTR_FLAG_STRICT,
-			 ATTR_TYPE_STR, MAIL_ATTR_DUMMY, scache_dummy,
-			 ATTR_TYPE_END) != 1
-#endif
-	    )
+	    || LOCAL_SEND_FD(vstream_fileno(client_stream), fd) < 0)
 	    msg_warn("%s: cannot send file descriptor: %m", myname);
 	if (close(fd) < 0)
 	    msg_warn("close(%d): %m", fd);
@@ -422,7 +401,6 @@ static void scache_service(VSTREAM *client_stream, char *unused_service,
      * dedicated to the scache service. All connection-management stuff is
      * handled by the common code in multi_server.c.
      */
-do {
     if (attr_scan(client_stream,
 		  ATTR_FLAG_MORE | ATTR_FLAG_STRICT,
 		  ATTR_TYPE_STR, MAIL_ATTR_REQ, scache_request,
@@ -443,7 +421,6 @@ do {
 		       ATTR_TYPE_END);
 	}
     }
-} while (vstream_peek(client_stream) > 0);
     vstream_fflush(client_stream);
 }
 
@@ -473,7 +450,7 @@ static void scache_status_dump(char *unused_name, char **unused_argv)
 	scache_endp_hits = scache_endp_miss = 0;
     }
     if (scache_dest_count || scache_endp_count || scache_sess_count) {
-	msg_info("statistics: max simultaneous domains=%d addresses=%d connection=%d",
+	msg_info("statistics: max simultaneous domains=%d addresses=%d sessions=%d",
 		 scache_dest_count, scache_endp_count, scache_sess_count);
 	scache_dest_count = 0;
 	scache_endp_count = 0;
