@@ -30,19 +30,10 @@
 #include <deliver_request.h>
 #include <scache.h>
 #include <string_list.h>
-#include <maps.h>
-#include <tok822.h>
 
  /*
-  * Postfix TLS library.
-  */
-#ifdef USE_TLS
-#include <tls.h>
-#endif
-
- /*
-  * State information associated with each SMTP delivery request.
-  * Session-specific state is stored separately.
+  * State information associated with each SMTP delivery. We're bundling the
+  * state so that we can give meaningful diagnostics in case of problems.
   */
 typedef struct SMTP_STATE {
     VSTREAM *src;			/* queue file stream */
@@ -53,12 +44,12 @@ typedef struct SMTP_STATE {
     int     space_left;			/* output length control */
 
     /*
-     * Connection cache support. The (nexthop_lookup_mx, nexthop_domain,
+     * Session cache support. The (nexthop_lookup_mx, nexthop_domain,
      * nexthop_port) triple is a parsed next-hop specification, and should be
      * a data type by itself. The (service, nexthop_mumble) members specify
-     * the name under which the first good connection should be cached. The
+     * the name under which the first good session should be cached. The
      * nexthop_mumble members are initialized by the connection management
-     * module. nexthop_domain is reset to null after one connection is saved
+     * module. nexthop_domain is reset to null after one session is saved
      * under the (service, nexthop_mumble) label, or upon exit from the
      * connection management module.
      */
@@ -110,10 +101,10 @@ typedef struct SMTP_STATE {
 #define SMTP_FEATURE_XFORWARD_ADDR	(1<<8)
 #define SMTP_FEATURE_XFORWARD_PROTO	(1<<9)
 #define SMTP_FEATURE_XFORWARD_HELO	(1<<10)
-#define SMTP_FEATURE_XFORWARD_DOMAIN	(1<<11)
+
 #define SMTP_FEATURE_BEST_MX		(1<<12)	/* for next-hop or fall-back */
 #define SMTP_FEATURE_RSET_REJECTED	(1<<13)	/* RSET probe rejected */
-#define SMTP_FEATURE_FROM_CACHE		(1<<14)	/* cached connection */
+#define SMTP_FEATURE_FROM_CACHE		(1<<14)	/* cached session */
 
  /*
   * Features that passivate under the endpoint.
@@ -131,7 +122,6 @@ typedef struct SMTP_STATE {
   * Misc flags.
   */
 #define SMTP_MISC_FLAG_LOOP_DETECT	(1<<0)
-#define	SMTP_MISC_FLAG_IN_STARTTLS	(1<<1)
 
 #define SMTP_MISC_FLAG_DEFAULT		SMTP_MISC_FLAG_LOOP_DETECT
 
@@ -150,26 +140,9 @@ extern int smtp_host_lookup_mask;	/* host lookup methods to use */
 #define SMTP_HOST_FLAG_DNS	(1<<0)
 #define SMTP_HOST_FLAG_NATIVE	(1<<1)
 
-extern SCACHE *smtp_scache;		/* connection cache instance */
+extern SCACHE *smtp_scache;		/* cache instance */
 extern STRING_LIST *smtp_cache_dest;	/* cached destinations */
 
-extern MAPS *smtp_ehlo_dis_maps;	/* ehlo keyword filter */
-
-extern MAPS *smtp_generic_maps;		/* make internal address valid */
-extern int smtp_ext_prop_mask;		/* address externsion propagation */
-
-#ifdef USE_TLS
-
-extern SSL_CTX *smtp_tls_ctx;		/* client-side TLS engine */
-
-#endif
-
-
- /*
-  * What's in a name?
-  */
-#define SMTP_HNAME(rr) (var_smtp_cname_overr ? (rr)->rname : (rr)->qname)
-
  /*
   * smtp_session.c
   */
@@ -179,7 +152,6 @@ typedef struct SMTP_SESSION {
     char   *host;			/* mail exchanger */
     char   *addr;			/* mail exchanger */
     char   *namaddr;			/* mail exchanger */
-    char   *helo;			/* helo response */
     unsigned port;			/* network byte order */
 
     VSTRING *buffer;			/* I/O buffer */
@@ -208,21 +180,10 @@ typedef struct SMTP_SESSION {
     sasl_callback_t *sasl_callbacks;	/* stateful callbacks */
 #endif
 
-    /*
-     * TLS related state.
-     */
-#ifdef USE_TLS
-    int     tls_use_tls;		/* can do TLS */
-    int     tls_enforce_tls;		/* must do TLS */
-    int     tls_enforce_peername;	/* cert must match */
-    TLScontext_t *tls_context;		/* TLS session state */
-    tls_info_t tls_info;		/* legacy */
-#endif
-
 } SMTP_SESSION;
 
 extern SMTP_SESSION *smtp_session_alloc(VSTREAM *, const char *,
-			         const char *, const char *, unsigned, int);
+			              const char *, const char *, unsigned, int);
 extern void smtp_session_free(SMTP_SESSION *);
 extern int smtp_session_passivate(SMTP_SESSION *, VSTRING *, VSTRING *);
 extern SMTP_SESSION *smtp_session_activate(int, VSTRING *, VSTRING *);
@@ -230,11 +191,6 @@ extern SMTP_SESSION *smtp_session_activate(int, VSTRING *, VSTRING *);
 #define SMTP_SESS_FLAG_NONE	0	/* no options */
 #define SMTP_SESS_FLAG_CACHE	(1<<0)	/* enable session caching */
 
-#ifdef USE_TLS
-extern void smtp_tls_list_init(void);
-
-#endif
-
  /*
   * smtp_connect.c
   */
@@ -325,13 +281,6 @@ extern VSTRING *smtp_unalias_addr(VSTRING *, const char *);
 extern SMTP_STATE *smtp_state_alloc(void);
 extern void smtp_state_free(SMTP_STATE *);
 
- /*
-  * smtp_map11.c
-  */
-extern int smtp_map11_external(VSTRING *, MAPS *, int);
-extern int smtp_map11_tree(TOK822 *, MAPS *, int);
-extern int smtp_map11_internal(VSTRING *, MAPS *, int);
-
 /* LICENSE
 /* .ad
 /* .fi
@@ -341,11 +290,4 @@ extern int smtp_map11_internal(VSTRING *, MAPS *, int);
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
-/*
-/*	TLS support originally by:
-/*	Lutz Jaenicke
-/*	BTU Cottbus
-/*	Allgemeine Elektrotechnik
-/*	Universitaetsplatz 3-4
-/*	D-03044 Cottbus, Germany
 /*--*/
