@@ -21,7 +21,6 @@
 /*	This module implements the client side of the SMTP protocol.
 /*
 /*	smtp_helo() performs the initial handshake with the SMTP server.
-/*	When TLS is enabled, this includes STARTTLS negotiations.
 /*
 /*	smtp_xfer() sends message envelope information followed by the
 /*	message data, and finishes the SMTP conversation. These operations
@@ -32,11 +31,11 @@
 /*
 /*	smtp_rset() sends a single RSET command and waits for the
 /*	response. In case of no response, or negative response, it
-/*	turns off connection caching.
+/*	turns off caching for the current session.
 /*
 /*	smtp_quit() sends a single QUIT command and waits for the
-/*	response if configured to do so. It always turns off connection
-/*	caching.
+/*	response if configured to do so. It always turns off caching
+/*	for the current session.
 /* DIAGNOSTICS
 /*	smtp_helo(), smtp_xfer(), smtp_rset() and smtp_quit() return
 /*	0 in case of success, -1 in case of failure. For smtp_xfer(),
@@ -77,13 +76,6 @@
 /*	Connection caching in cooperation with:
 /*	Victor Duchovni
 /*	Morgan Stanley
-/*
-/*	TLS support originally by:
-/*	Lutz Jaenicke
-/*	BTU Cottbus
-/*	Allgemeine Elektrotechnik
-/*	Universitaetsplatz 3-4
-/*	D-03044 Cottbus, Germany
 /*--*/
 
 /* System library. */
@@ -91,7 +83,6 @@
 #include <sys_defs.h>
 #include <sys/stat.h>
 #include <sys/socket.h>			/* shutdown(2) */
-#include <netinet/in.h>			/* ntohs() */
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>			/* 44BSD stdarg.h uses abort() */
@@ -130,12 +121,6 @@
 #include <quote_821_local.h>
 #include <mail_proto.h>
 #include <mime_state.h>
-#include <ehlo_mask.h>
-#include <maps.h>
-#include <tok822.h>
-#include <mail_addr_map.h>
-#include <ext_prop.h>
-#include <lex_822.h>
 
 /* Application-specific. */
 
@@ -220,11 +205,9 @@ char   *xfer_request[SMTP_STATE_LAST] = {
     "QUIT command",
 };
 
-static int smtp_start_tls(SMTP_STATE *, int);
-
 /* smtp_helo - perform initial handshake with SMTP server */
 
-int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
+int     smtp_helo(SMTP_STATE *state, int misc_flags)
 {
     char   *myname = "smtp_helo";
     SMTP_SESSION *session = state->session;
@@ -240,17 +223,9 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
 	XFORWARD_ADDR, SMTP_FEATURE_XFORWARD_ADDR,
 	XFORWARD_PROTO, SMTP_FEATURE_XFORWARD_PROTO,
 	XFORWARD_HELO, SMTP_FEATURE_XFORWARD_HELO,
-	XFORWARD_DOMAIN, SMTP_FEATURE_XFORWARD_DOMAIN,
 	0, 0,
     };
     SOCKOPT_SIZE optlen;
-    const char *ehlo_words;
-    int     discard_mask;
-
-#ifdef USE_TLS
-    int     saved_features = session->features;
-
-#endif
 
     /*
      * Prepare for disaster.
@@ -258,69 +233,54 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
     smtp_timeout_setup(state->session->stream, var_smtp_helo_tmout);
     if ((except = vstream_setjmp(state->session->stream)) != 0)
 	return (smtp_stream_except(state, except,
-			      "performing the initial protocol handshake"));
+				   "receiving the initial SMTP greeting"));
 
     /*
-     * If not recursing after STARTTLS, examine the server greeting banner
-     * and decide if we are going to send EHLO as the next command.
+     * Read and parse the server's SMTP greeting banner.
      */
-    if ((misc_flags & SMTP_MISC_FLAG_IN_STARTTLS) == 0) {
+    switch ((resp = smtp_chat_resp(session))->code / 100) {
+    case 2:
+	break;
+    case 5:
+	if (var_smtp_skip_5xx_greeting)
+	    resp->code = 400;
+    default:
+	return (smtp_site_fail(state, resp->code,
+			       "host %s refused to talk to me: %s",
+			       session->namaddr,
+			       translit(resp->str, "\n", " ")));
+    }
 
-	/*
-	 * Read and parse the server's SMTP greeting banner.
-	 */
-	switch ((resp = smtp_chat_resp(session))->code / 100) {
-	case 2:
-	    break;
-	case 5:
-	    if (var_smtp_skip_5xx_greeting)
-		resp->code = 400;
-	default:
-	    return (smtp_site_fail(state, resp->code,
-				   "host %s refused to talk to me: %s",
-				   session->namaddr,
-				   translit(resp->str, "\n", " ")));
-	}
+    /*
+     * XXX Some PIX firewall versions require flush before ".<CR><LF>" so it
+     * does not span a packet boundary. This hurts performance so it is not
+     * on by default.
+     */
+    if (resp->str[strspn(resp->str, "20 *\t\n")] == 0)
+	session->features |= SMTP_FEATURE_MAYBEPIX;
 
-	/*
-	 * XXX Some PIX firewall versions require flush before ".<CR><LF>" so
-	 * it does not span a packet boundary. This hurts performance so it
-	 * is not on by default.
-	 */
-	if (resp->str[strspn(resp->str, "20 *\t\n")] == 0)
-	    session->features |= SMTP_FEATURE_MAYBEPIX;
-
-	/*
-	 * See if we are talking to ourself. This should not be possible with
-	 * the way we implement DNS lookups. However, people are known to
-	 * sometimes screw up the naming service. And, mailer loops are still
-	 * possible when our own mailer routing tables are mis-configured.
-	 */
-	words = resp->str;
-	(void) mystrtok(&words, "- \t\n");
-	for (n = 0; (word = mystrtok(&words, " \t\n")) != 0; n++) {
-	    if (n == 0 && strcasecmp(word, var_myhostname) == 0) {
-		if (misc_flags & SMTP_MISC_FLAG_LOOP_DETECT)
-		    msg_warn("host %s greeted me with my own hostname %s",
-			     session->namaddr, var_myhostname);
-	    } else if (strcasecmp(word, "ESMTP") == 0)
-		session->features |= SMTP_FEATURE_ESMTP;
-	}
-	if (var_smtp_always_ehlo
-	    && (session->features & SMTP_FEATURE_MAYBEPIX) == 0)
+    /*
+     * See if we are talking to ourself. This should not be possible with the
+     * way we implement DNS lookups. However, people are known to sometimes
+     * screw up the naming service. And, mailer loops are still possible when
+     * our own mailer routing tables are mis-configured.
+     */
+    words = resp->str;
+    (void) mystrtok(&words, "- \t\n");
+    for (n = 0; (word = mystrtok(&words, " \t\n")) != 0; n++) {
+	if (n == 0 && strcasecmp(word, var_myhostname) == 0) {
+	    if (misc_flags & SMTP_MISC_FLAG_LOOP_DETECT)
+		msg_warn("host %s greeted me with my own hostname %s",
+			 session->namaddr, var_myhostname);
+	} else if (strcasecmp(word, "ESMTP") == 0)
 	    session->features |= SMTP_FEATURE_ESMTP;
-	if (var_smtp_never_ehlo
-	    || (session->features & SMTP_FEATURE_MAYBEPIX) != 0)
-	    session->features &= ~SMTP_FEATURE_ESMTP;
     }
-
-    /*
-     * If recursing after STARTTLS, there is no server greeting banner.
-     * Always send EHLO as the next command.
-     */
-    else {
+    if (var_smtp_always_ehlo
+	&& (session->features & SMTP_FEATURE_MAYBEPIX) == 0)
 	session->features |= SMTP_FEATURE_ESMTP;
-    }
+    if (var_smtp_never_ehlo
+	|| (session->features & SMTP_FEATURE_MAYBEPIX) != 0)
+	session->features &= ~SMTP_FEATURE_ESMTP;
 
     /*
      * Return the compliment. Fall back to SMTP if our ESMTP recognition
@@ -338,87 +298,53 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
 				   "host %s refused to talk to me: %s",
 				   session->namaddr,
 				   translit(resp->str, "\n", " ")));
+	return (0);
     }
 
     /*
-     * No early returns allowed, to ensure consistent handling of TLS and
-     * SASL policies.
+     * Pick up some useful features offered by the SMTP server. XXX Until we
+     * have a portable routine to convert from string to off_t with proper
+     * overflow detection, ignore the message size limit advertised by the
+     * SMTP server. Otherwise, we might do the wrong thing when the server
+     * advertises a really huge message size limit.
+     * 
+     * XXX Allow for "code (SP|-) ehlo-keyword (SP|=) ehlo-param...", because
+     * MicroSoft implemented AUTH based on an old draft.
      */
-    if (session->features & SMTP_FEATURE_ESMTP) {
-
-	/*
-	 * Determine what server EHLO keywords to ignore, typically to avoid
-	 * inter-operability problems.
-	 */
-	if (smtp_ehlo_dis_maps == 0
-	    || (ehlo_words = maps_find(smtp_ehlo_dis_maps,
-				       state->session->addr, 0)) == 0)
-	    ehlo_words = var_smtp_ehlo_dis_words;
-	discard_mask = ehlo_mask(ehlo_words);
-	if (discard_mask && !(discard_mask & EHLO_MASK_SILENT))
-	    msg_info("discarding EHLO keywords: %s",
-		     str_ehlo_mask(discard_mask));
-
-	/*
-	 * Pick up some useful features offered by the SMTP server.
-	 * 
-	 * XXX Allow for "code (SP|-) ehlo-keyword (SP|=) ehlo-param...",
-	 * because MicroSoft implemented AUTH based on an old draft.
-	 */
-	lines = resp->str;
-	for (n = 0; (words = mystrtok(&lines, "\n")) != 0; /* see below */ ) {
-	    if (mystrtok(&words, "- ")
-		&& (word = mystrtok(&words, " \t=")) != 0) {
-		if (n == 0) {
-		    if (session->helo != 0)
-			myfree(session->helo);
-		    session->helo = lowercase(mystrdup(word));
-		    if (strcasecmp(word, var_myhostname) == 0
-			&& (misc_flags & SMTP_MISC_FLAG_LOOP_DETECT) != 0) {
-			msg_warn("host %s replied to HELO/EHLO"
-				 " with my own hostname %s",
-				 session->namaddr, var_myhostname);
-			return (smtp_site_fail(state,
-					       (session->features & SMTP_FEATURE_BEST_MX) ? 550 : 450,
-					 "mail for %s loops back to myself",
-					       request->nexthop));
-		    }
-		} else if (strcasecmp(word, "8BITMIME") == 0) {
-		    if ((discard_mask & EHLO_MASK_8BITMIME) == 0)
-			session->features |= SMTP_FEATURE_8BITMIME;
-		} else if (strcasecmp(word, "PIPELINING") == 0) {
-		    if ((discard_mask & EHLO_MASK_PIPELINING) == 0)
-			session->features |= SMTP_FEATURE_PIPELINING;
-		} else if (strcasecmp(word, "XFORWARD") == 0) {
-		    if ((discard_mask & EHLO_MASK_XFORWARD) == 0)
-			while ((word = mystrtok(&words, " \t")) != 0)
-			    session->features |= name_code(xforward_features,
+    lines = resp->str;
+    while ((words = mystrtok(&lines, "\n")) != 0) {
+	if (mystrtok(&words, "- ") && (word = mystrtok(&words, " \t=")) != 0) {
+	    if (strcasecmp(word, "8BITMIME") == 0)
+		session->features |= SMTP_FEATURE_8BITMIME;
+	    else if (strcasecmp(word, "PIPELINING") == 0)
+		session->features |= SMTP_FEATURE_PIPELINING;
+	    else if (strcasecmp(word, "XFORWARD") == 0)
+		while ((word = mystrtok(&words, " \t")) != 0)
+		    session->features |= name_code(xforward_features,
 						 NAME_CODE_FLAG_NONE, word);
-		} else if (strcasecmp(word, "SIZE") == 0) {
-		    if ((discard_mask & EHLO_MASK_SIZE) == 0) {
-			session->features |= SMTP_FEATURE_SIZE;
-			if ((word = mystrtok(&words, " \t")) != 0) {
-			    if (!alldig(word))
-				msg_warn("bad EHLO SIZE limit \"%s\" from %s",
-					 word, session->namaddr);
-			    else
-				session->size_limit = off_cvt_string(word);
-			}
-		    }
-#ifdef USE_TLS
-		} else if (strcasecmp(word, "STARTTLS") == 0) {
-		    /* Ignored later if we already sent STARTTLS. */
-		    if ((discard_mask & EHLO_MASK_STARTTLS) == 0)
-			session->features |= SMTP_FEATURE_STARTTLS;
-#endif
+	    else if (strcasecmp(word, "SIZE") == 0) {
+		session->features |= SMTP_FEATURE_SIZE;
+		if ((word = mystrtok(&words, " \t")) != 0) {
+		    if (!alldig(word))
+			msg_warn("bad size limit \"%s\" in EHLO reply from %s",
+				 word, session->namaddr);
+		    else
+			session->size_limit = off_cvt_string(word);
+		}
+	    }
 #ifdef USE_SASL_AUTH
-		} else if (var_smtp_sasl_enable
-			   && strcasecmp(word, "AUTH") == 0) {
-		    if ((discard_mask & EHLO_MASK_AUTH) == 0)
-			smtp_sasl_helo_auth(session, words);
+	    else if (var_smtp_sasl_enable && strcasecmp(word, "AUTH") == 0)
+		smtp_sasl_helo_auth(session, words);
 #endif
+	    else if (strcasecmp(word, var_myhostname) == 0) {
+		if (misc_flags & SMTP_MISC_FLAG_LOOP_DETECT) {
+		    msg_warn("host %s replied to HELO/EHLO with my own hostname %s",
+			     session->namaddr, var_myhostname);
+		    return (smtp_site_fail(state,
+		     (session->features & SMTP_FEATURE_BEST_MX) ? 550 : 450,
+					 "mail for %s loops back to myself",
+					   request->nexthop));
 		}
-		n++;
 	    }
 	}
     }
@@ -438,9 +364,6 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
      * we are reading in the responses. In addition to TCP buffering we have
      * to be aware of application-level buffering by the vstream module,
      * which is limited to a couple kbytes.
-     * 
-     * XXX No need to do this before and after STARTTLS, but it's not a big deal
-     * if we do.
      */
     if (session->features & SMTP_FEATURE_PIPELINING) {
 	optlen = sizeof(session->sndbufsize);
@@ -462,97 +385,6 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
 	session->sndbufsize = 0;
     }
 
-#ifdef USE_TLS
-
-    /*
-     * Skip this part if we already sent STARTTLS.
-     */
-    if ((misc_flags & SMTP_MISC_FLAG_IN_STARTTLS) == 0) {
-
-	/*
-	 * Optionally log unused STARTTLS opportunities.
-	 */
-	if ((session->features & SMTP_FEATURE_STARTTLS) &&
-	    (var_smtp_tls_note_starttls_offer) &&
-	    (!(session->tls_enforce_tls || session->tls_use_tls)))
-	    msg_info("Host offered STARTTLS: [%s]", session->host);
-
-	/*
-	 * Decide whether or not to send STARTTLS.
-	 */
-	if ((session->features & SMTP_FEATURE_STARTTLS) != 0
-	    && smtp_tls_ctx != 0
-	    && (session->tls_use_tls || session->tls_enforce_tls)) {
-
-	    /*
-	     * Prepare for disaster.
-	     */
-	    smtp_timeout_setup(state->session->stream, var_smtp_starttls_tmout);
-	    if ((except = vstream_setjmp(state->session->stream)) != 0)
-		return (smtp_stream_except(state, except,
-					"receiving the STARTTLS response"));
-
-	    /*
-	     * Send STARTTLS. Recurse when the server accepts STARTTLS, after
-	     * resetting the SASL and EHLO features lists.
-	     * 
-	     * XXX Reset the SASL mechanism list to avoid spurious warnings. We
-	     * need a routine to reset the list instead of groping data here.
-	     * 
-	     * XXX Should not there be an smtp_sasl_tls_security_options feature
-	     * to allow different mechanisms across TLS tunnels than across
-	     * plain-text connections?
-	     */
-	    smtp_chat_cmd(session, "STARTTLS");
-	    if ((resp = smtp_chat_resp(session))->code / 100 == 2) {
-#ifdef USE_SASL_AUTH
-		if (session->sasl_mechanism_list) {
-		    myfree(session->sasl_mechanism_list);
-		    session->sasl_mechanism_list = 0;
-		}
-#endif
-		session->features = saved_features;
-		misc_flags |= SMTP_MISC_FLAG_IN_STARTTLS;
-		return (smtp_start_tls(state, misc_flags));
-	    }
-
-	    /*
-	     * Give up if we must use TLS but the server rejects STARTTLS
-	     * although support for it was announced in the EHLO response.
-	     */
-	    session->features &= ~SMTP_FEATURE_STARTTLS;
-	    if (session->tls_enforce_tls)
-		return (smtp_site_fail(state, resp->code,
-		    "TLS is required, but host %s refused to start TLS: %s",
-				       session->namaddr,
-				       translit(resp->str, "\n", " ")));
-	    /* Else try to continue in plain-text mode. */
-	}
-
-	/*
-	 * Give up if we must use TLS but can't for various reasons.
-	 * 
-	 * 200412 Be sure to provide the default clause at the bottom of this
-	 * block. When TLS is required we must never, ever, end up in
-	 * plain-text mode.
-	 */
-	if (session->tls_enforce_tls) {
-	    if (!(session->features & SMTP_FEATURE_STARTTLS)) {
-		return (smtp_site_fail(state, 450,
-			  "TLS is required, but was not offered by host %s",
-				       session->namaddr));
-	    } else if (smtp_tls_ctx == 0) {
-		return (smtp_site_fail(state, 450,
-		     "TLS is required, but our TLS engine is unavailable"));
-	    } else {
-		msg_warn("%s: TLS is required but unavailable, don't know why",
-			 myname);
-		return (smtp_site_fail(state, 450,
-				     "TLS is required, but not available"));
-	    }
-	}
-    }
-#endif
 #ifdef USE_SASL_AUTH
     if (var_smtp_sasl_enable && (session->features & SMTP_FEATURE_AUTH))
 	return (smtp_sasl_helo_login(state));
@@ -561,118 +393,6 @@ int     smtp_helo(SMTP_STATE *state, NOCLOBBER int misc_flags)
     return (0);
 }
 
-#ifdef USE_TLS
-
-/* smtp_start_tls - turn on TLS and recurse into the HELO dialog */
-
-static int smtp_start_tls(SMTP_STATE *state, int misc_flags)
-{
-    SMTP_SESSION *session = state->session;
-    VSTRING *serverid;
-
-    /*
-     * Turn off SMTP connection caching. When the TLS handshake succeeds, we
-     * can't reuse the SMTP connection. Reason: we can't turn off TLS in one
-     * process, save the connection to the cache which is shared with all
-     * SMTP clients, migrate the connection to another SMTP client, and
-     * resume TLS there. When the TLS handshake fails, we can't reuse the
-     * SMTP connection either, because the conversation is in an unknown
-     * state.
-     */
-    session->reuse_count = 0;
-
-    /*
-     * The actual TLS handshake may succeed, but tls_client_start() may fail
-     * anyway, for example because server certificate verification is
-     * required but failed, or because enforce_peername is required but the
-     * names listed in the server certificate don't match the peer hostname.
-     * 
-     * XXX When tls_client_start() fails then we don't know what state the SMTP
-     * connection is in, so we give up on this connection even if we are not
-     * required to use TLS.
-     * 
-     * XXX Other tests for specific combinations of required/failed behavior
-     * follow below AFTER the tls_client_start() call. These tests should be
-     * done inside tls_client_start() or its call-backs, to keep the SMTP
-     * client code clean (as it is in the SMTP server).
-     * 
-     * The following assumes sites that use TLS in a perverse configuration:
-     * multiple hosts per hostname, or even multiple hosts per IP address.
-     * All this without a shared TLS session cache, and they still want to
-     * use TLS session caching???
-     */
-    serverid = vstring_alloc(10);
-    vstring_sprintf(serverid, "%s:%s:%u",
-		    session->host, session->addr,
-		    ntohs(session->port));
-    if (session->helo && strcasecmp(session->host, session->helo) != 0)
-	vstring_sprintf_append(serverid, ":%s", session->helo);
-    session->tls_context =
-	tls_client_start(smtp_tls_ctx, session->stream,
-			 var_smtp_starttls_tmout,
-			 session->tls_enforce_peername,
-			 session->host,
-			 lowercase(vstring_str(serverid)),
-			 &(session->tls_info));
-    vstring_free(serverid);
-    if (session->tls_context == 0)
-	return (smtp_site_fail(state, 450,
-			       "Cannot start TLS: handshake failure"));
-
-    /*
-     * Give up when TLS is required, we can parse the server certificate's
-     * CommonName field, but server certificate verification failed.
-     * 
-     * In enforce_peername state, the handshake would already have been
-     * terminated by the certificate verification call-back routine, so the
-     * check here is for logging only.
-     * 
-     * XXX It appears that the CommonName field is used as an indicator that a
-     * server certificate is available. If the latter is what we want, then
-     * we should test for that instead.
-     */
-    if (session->tls_info.peer_CN != NULL) {
-	if (!session->tls_info.peer_verified) {
-	    msg_info("Server certificate could not be verified");
-	    if (session->tls_enforce_peername) {
-		tls_client_stop(smtp_tls_ctx, session->stream,
-				var_smtp_starttls_tmout, 1,
-				&(session->tls_info));
-		session->tls_context = 0;
-		return (smtp_site_fail(state, 450,
-			  "TLS failure: Cannot verify server certificate"));
-	    }
-	}
-    }
-
-    /*
-     * Give up when TLS is required but no server certificate is available
-     * (or we could not parse the certificate's CommonName) field.
-     * 
-     * XXX The test below is not accurate: the server hostname verification may
-     * use the dNSNames instead of the CommonName. We really should be
-     * testing if a certificate is available.
-     */
-    else {
-	if (session->tls_enforce_peername) {
-	    tls_client_stop(smtp_tls_ctx, session->stream,
-			    var_smtp_starttls_tmout, 1,
-			    &(session->tls_info));
-	    session->tls_context = 0;
-	    return (smtp_site_fail(state, 450,
-			     "TLS failure: Cannot verify server hostname"));
-	}
-    }
-
-    /*
-     * At this point we have to re-negotiate the "EHLO" to reget the
-     * feature-list.
-     */
-    return (smtp_helo(state, misc_flags));
-}
-
-#endif
-
 /* smtp_text_out - output one header/body record */
 
 static void smtp_text_out(void *context, int rec_type,
@@ -719,23 +439,6 @@ static void smtp_text_out(void *context, int rec_type,
     } while (data_left > 0);
 }
 
-/* smtp_format_out - output one header/body record */
-
-static void PRINTFLIKE(3, 4) smtp_format_out(void *, int, const char *,...);
-
-static void smtp_format_out(void *context, int rec_type, const char *fmt,...)
-{
-    static VSTRING *vp;
-    va_list ap;
-
-    if (vp == 0)
-	vp = vstring_alloc(100);
-    va_start(ap, fmt);
-    vstring_vsprintf(vp, fmt, ap);
-    va_end(ap);
-    smtp_text_out(context, rec_type, vstring_str(vp), VSTRING_LEN(vp), 0);
-}
-
 /* smtp_header_out - output one message header */
 
 static void smtp_header_out(void *context, int unused_header_class,
@@ -746,10 +449,6 @@ static void smtp_header_out(void *context, int unused_header_class,
     char   *line;
     char   *next_line;
 
-    /*
-     * This code destroys the header. We could try to avoid clobbering it,
-     * but we're not going to use the data any further.
-     */
     for (line = start; line; line = next_line) {
 	next_line = split_at(line, '\n');
 	smtp_text_out(context, REC_TYPE_NORM, line, next_line ?
@@ -757,94 +456,6 @@ static void smtp_header_out(void *context, int unused_header_class,
     }
 }
 
-/* smtp_header_rewrite - rewrite message header before output */
-
-static void smtp_header_rewrite(void *context, int header_class,
-			             HEADER_OPTS *header_info, VSTRING *buf,
-				        off_t offset)
-{
-    SMTP_STATE *state = (SMTP_STATE *) context;
-    int     did_rewrite = 0;
-    char   *line;
-    char   *start;
-    char   *next_line;
-    char   *end_line;
-
-    /*
-     * Rewrite primary header addresses that match the smtp_generic_maps. The
-     * cleanup server already enforces that all headers have proper lengths
-     * and that all addresses are in proper form, so we don't have to repeat
-     * that.
-     */
-    if (header_info && header_class == MIME_HDR_PRIMARY
-	&& (header_info->flags & (HDR_OPT_SENDER | HDR_OPT_RECIP)) != 0) {
-	TOK822 *tree;
-	TOK822 **addr_list;
-	TOK822 **tpp;
-
-	tree = tok822_parse(vstring_str(buf)
-			    + strlen(header_info->name) + 1);
-	addr_list = tok822_grep(tree, TOK822_ADDR);
-	for (tpp = addr_list; *tpp; tpp++)
-	    did_rewrite |= smtp_map11_tree(tpp[0], smtp_generic_maps,
-				     smtp_ext_prop_mask & EXT_PROP_GENERIC);
-	if (did_rewrite) {
-	    vstring_truncate(buf, strlen(header_info->name));
-	    vstring_strcat(buf, ": ");
-	    tok822_externalize(buf, tree, TOK822_STR_HEAD);
-	}
-	myfree((char *) addr_list);
-	tok822_free_tree(tree);
-    }
-
-    /*
-     * Pass through unmodified headers without reconstruction.
-     */
-    if (did_rewrite == 0) {
-	smtp_header_out(context, header_class, header_info, buf, offset);
-	return;
-    }
-
-    /*
-     * A rewritten address list contains one address per line. The code below
-     * replaces newlines by spaces, to fit as many addresses on a line as
-     * possible (without rearranging the order of addresses). Prepending
-     * white space to the beginning of lines is delegated to the output
-     * routine.
-     * 
-     * Code derived from cleanup_fold_header().
-     */
-    for (line = start = vstring_str(buf); line != 0; line = next_line) {
-	end_line = line + strcspn(line, "\n");
-	if (line > start) {
-	    if (end_line - start < 70) {	/* TAB counts as one */
-		line[-1] = ' ';
-	    } else {
-		start = line;
-	    }
-	}
-	next_line = *end_line ? end_line + 1 : 0;
-    }
-
-    /*
-     * Prepend a tab to continued header lines that went through the address
-     * rewriting machinery. Just like smtp_header_out(), this code destroys
-     * the header. We could try to avoid clobbering it, but we're not going
-     * to use the data any further.
-     * 
-     * Code derived from cleanup_out_header().
-     */
-    for (line = start = vstring_str(buf); line != 0; line = next_line) {
-	next_line = split_at(line, '\n');
-	if (line == start || IS_SPACE_TAB(*line)) {
-	    smtp_text_out(state, REC_TYPE_NORM, line, next_line ?
-			  next_line - line - 1 : strlen(line), offset);
-	} else {
-	    smtp_format_out(state, REC_TYPE_NORM, "\t%s", line);
-	}
-    }
-}
-
 /* smtp_loop - exercise the SMTP protocol engine */
 
 static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
@@ -872,11 +483,13 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
     /*
      * Macros for readability.
      */
-#define REWRITE_ADDRESS(dst, src) do { \
-	vstring_strcpy(dst, src); \
-	if (*(src) && smtp_generic_maps) \
-	    smtp_map11_internal(dst, smtp_generic_maps, \
-		smtp_ext_prop_mask & EXT_PROP_GENERIC); \
+#define REWRITE_ADDRESS(dst, mid, src) do { \
+	if (*(src) && var_smtp_quote_821_env) { \
+	    quote_821_local(mid, src); \
+	    smtp_unalias_addr(dst, vstring_str(mid)); \
+	} else { \
+	    vstring_strcpy(dst, src); \
+	} \
     } while (0)
 
 #define QUOTE_ADDRESS(dst, src) do { \
@@ -888,8 +501,6 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
     } while (0)
 
 #define RETURN(x) do { \
-	if (recv_state != SMTP_STATE_LAST) \
-	    DONT_CACHE_THIS_SESSION; \
 	vstring_free(next_command); \
 	if (session->mime_state) \
 	    session->mime_state = mime_state_free(session->mime_state); \
@@ -1028,12 +639,6 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 		vstring_sprintf_append(next_command, " %s=%s",
 		   XFORWARD_HELO, DEL_REQ_ATTR_AVAIL(request->client_helo) ?
 			       request->client_helo : XFORWARD_UNAVAILABLE);
-	    if (session->features & SMTP_FEATURE_XFORWARD_DOMAIN)
-		vstring_sprintf_append(next_command, " %s=%s", XFORWARD_DOMAIN,
-			 DEL_REQ_ATTR_AVAIL(request->rewrite_context) == 0 ?
-				       XFORWARD_UNAVAILABLE :
-		     strcmp(request->rewrite_context, MAIL_ATTR_RWR_LOCAL) ?
-				  XFORWARD_DOM_REMOTE : XFORWARD_DOM_LOCAL);
 	    next_state = SMTP_STATE_MAIL;
 	    break;
 
@@ -1041,8 +646,7 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 	     * Build the MAIL FROM command.
 	     */
 	case SMTP_STATE_MAIL:
-	    REWRITE_ADDRESS(session->scratch2, request->sender);
-	    QUOTE_ADDRESS(session->scratch, vstring_str(session->scratch2));
+	    QUOTE_ADDRESS(session->scratch, request->sender);
 	    vstring_sprintf(next_command, "MAIL FROM:<%s>",
 			    vstring_str(session->scratch));
 	    if (session->features & SMTP_FEATURE_SIZE)	/* RFC 1870 */
@@ -1075,8 +679,7 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 	     */
 	case SMTP_STATE_RCPT:
 	    rcpt = request->rcpt_list.info + send_rcpt;
-	    REWRITE_ADDRESS(session->scratch2, rcpt->address);
-	    QUOTE_ADDRESS(session->scratch, vstring_str(session->scratch2));
+	    QUOTE_ADDRESS(session->scratch, rcpt->address);
 	    vstring_sprintf(next_command, "RCPT TO:<%s>",
 			    vstring_str(session->scratch));
 	    if ((next_rcpt = send_rcpt + 1) == SMTP_RCPT_LEFT(state))
@@ -1387,11 +990,9 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 		(var_disable_mime_oconv == 0
 		 && (session->features & SMTP_FEATURE_8BITMIME) == 0
 		 && strcmp(request->encoding, MAIL_ATTR_ENC_7BIT) != 0);
-	    if (downgrading || smtp_generic_maps)
+	    if (downgrading)
 		session->mime_state = mime_state_alloc(MIME_OPT_DOWNGRADE
 						  | MIME_OPT_REPORT_NESTING,
-						       smtp_generic_maps ?
-						       smtp_header_rewrite :
 						       smtp_header_out,
 						     (MIME_STATE_ANY_END) 0,
 						       smtp_text_out,
@@ -1411,7 +1012,7 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 	    while ((rec_type = rec_get(state->src, session->scratch, 0)) > 0) {
 		if (rec_type != REC_TYPE_NORM && rec_type != REC_TYPE_CONT)
 		    break;
-		if (session->mime_state == 0) {
+		if (downgrading == 0) {
 		    smtp_text_out((void *) state, rec_type,
 				  vstring_str(session->scratch),
 				  VSTRING_LEN(session->scratch),
@@ -1422,7 +1023,8 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 					  vstring_str(session->scratch),
 					  VSTRING_LEN(session->scratch));
 		    if (mime_errs) {
-			smtp_mesg_fail(state, 554, "%s",
+			smtp_mesg_fail(state, 554,
+				       "MIME 7-bit conversion failed: %s",
 				       mime_state_error(mime_errs));
 			RETURN(0);
 		    }
@@ -1439,13 +1041,12 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 		 * ending in newline via /usr/sbin/sendmail while MIME input
 		 * processing is turned off, and MIME 8bit->7bit conversion
 		 * is requested upon delivery.
-		 * 
-		 * Or some error while doing generic address mapping.
 		 */
 		mime_errs =
 		    mime_state_update(session->mime_state, rec_type, "", 0);
 		if (mime_errs) {
-		    smtp_mesg_fail(state, 554, "%s",
+		    smtp_mesg_fail(state, 554,
+				   "MIME 7-bit conversion failed: %s",
 				   mime_state_error(mime_errs));
 		    RETURN(0);
 		}
@@ -1456,16 +1057,13 @@ static int smtp_loop(SMTP_STATE *state, NOCLOBBER int send_state,
 		- var_smtp_pix_thresh) {
 		msg_info("%s: enabling PIX <CRLF>.<CRLF> workaround for %s",
 			 request->queue_id, session->namaddr);
-		smtp_flush(session->stream);	/* hurts performance */
+		vstream_fflush(session->stream);/* hurts performance */
 		sleep(var_smtp_pix_delay);	/* not to mention this */
 	    }
 	    if (vstream_ferror(state->src))
 		msg_fatal("queue file read error");
-	    if (rec_type != REC_TYPE_XTRA) {
-		msg_warn("%s: bad record type: %d in message content",
-			 request->queue_id, rec_type);
+	    if (rec_type != REC_TYPE_XTRA)
 		RETURN(mark_corrupt(state->src));
-	    }
 	}
 
 	/*
