@@ -27,20 +27,12 @@
 #include <vstream.h>
 #include <vstring.h>
 #include <argv.h>
-#include <myaddrinfo.h>
 
  /*
   * Global library.
   */
 #include <mail_stream.h>
 
- /*
-  * Postfix TLS library.
-  */
-#ifdef USE_TLS
-#include <tls.h>
-#endif
-
  /*
   * Variables that keep track of conversation state. There is only one SMTP
   * conversation at a time, so the state variables can be made global. And
@@ -58,11 +50,9 @@ typedef struct {
     char   *name;			/* name for access control */
     char   *addr;			/* address for access control */
     char   *namaddr;			/* name[address] */
-    char   *rfc_addr;			/* address for RFC 2821 */
     char   *protocol;			/* email protocol */
     char   *helo_name;			/* helo/ehlo parameter */
     char   *ident;			/* message identifier */
-    char   *domain;			/* rewrite context */
 } SMTPD_XFORWARD_ATTR;
 
 typedef struct SMTPD_STATE {
@@ -74,8 +64,6 @@ typedef struct SMTPD_STATE {
     char   *name;			/* client hostname */
     char   *addr;			/* client host address string */
     char   *namaddr;			/* combined name and address */
-    char   *rfc_addr;			/* address for RFC 2821 */
-    struct sockaddr_storage sockaddr;	/* binary client endpoint */
     int     peer_code;			/* 2=ok, 4=soft, 5=hard */
     int     error_count;		/* reset after DOT */
     int     error_mask;			/* client errors */
@@ -97,10 +85,8 @@ typedef struct SMTPD_STATE {
     char   *where;			/* protocol stage */
     int     recursion;			/* Kellerspeicherpegelanzeiger */
     off_t   msg_size;			/* MAIL FROM message size */
-    off_t   act_size;			/* END-OF-DATA message size */
     int     junk_cmds;			/* counter */
     int     rcpt_overshoot;		/* counter */
-    char   *rewrite_context;		/* address rewriting context */
 
     /*
      * SASL specific.
@@ -151,18 +137,6 @@ typedef struct SMTPD_STATE {
      * XFORWARD server state.
      */
     SMTPD_XFORWARD_ATTR xforward;	/* up-stream logging info */
-
-    /*
-     * TLS related state.
-     */
-#ifdef USE_TLS
-    int     tls_use_tls;		/* can use TLS */
-    int     tls_enforce_tls;		/* must use TLS */
-    int     tls_auth_only;		/* use SASL over TLS only */
-    TLScontext_t *tls_context;		/* TLS session state */
-    tls_info_t tls_info;		/* legacy */
-#endif
-
 } SMTPD_STATE;
 
 #define SMTPD_STATE_XFORWARD_INIT  (1<<0)	/* xforward preset done */
@@ -171,7 +145,6 @@ typedef struct SMTPD_STATE {
 #define SMTPD_STATE_XFORWARD_PROTO (1<<3)	/* protocol received */
 #define SMTPD_STATE_XFORWARD_HELO  (1<<4)	/* client helo received */
 #define SMTPD_STATE_XFORWARD_IDENT (1<<5)	/* message identifier */
-#define SMTPD_STATE_XFORWARD_DOMAIN (1<<6)	/* message identifier */
 
 #define SMTPD_STATE_XFORWARD_CLIENT_MASK \
 	(SMTPD_STATE_XFORWARD_NAME | SMTPD_STATE_XFORWARD_ADDR \
@@ -200,7 +173,6 @@ extern void smtpd_state_reset(SMTPD_STATE *);
 #define CLIENT_HELO_UNKNOWN	0
 #define CLIENT_PROTO_UNKNOWN	CLIENT_ATTR_UNKNOWN
 #define CLIENT_IDENT_UNKNOWN	0
-#define CLIENT_DOMAIN_UNKNOWN	0
 
 #define IS_AVAIL_CLIENT_ATTR(v)	((v) && strcmp((v), CLIENT_ATTR_UNKNOWN))
 
@@ -210,7 +182,6 @@ extern void smtpd_state_reset(SMTPD_STATE *);
 #define IS_AVAIL_CLIENT_HELO(v)	((v) != 0)
 #define IS_AVAIL_CLIENT_PROTO(v) IS_AVAIL_CLIENT_ATTR(v)
 #define IS_AVAIL_CLIENT_IDENT(v) ((v) != 0)
-#define IS_AVAIL_CLIENT_DOMAIN(v) ((v) != 0)
 
  /*
   * If running in stand-alone mode, do not try to talk to Postfix daemons but
@@ -257,19 +228,16 @@ extern void smtpd_peer_reset(SMTPD_STATE *state);
 	(((s)->xforward.flags & SMTPD_STATE_XFORWARD_CLIENT_MASK) ? \
 	    (s)->xforward.a : (s)->a)
 
-#define FORWARD_ADDR(s)		FORWARD_CLIENT_ATTR((s), rfc_addr)
+#define FORWARD_IDENT_ATTR(s) \
+	(((s)->xforward.flags & SMTPD_STATE_XFORWARD_IDENT) ? \
+	    (s)->queue_id : (s)->ident)
+
+#define FORWARD_ADDR(s)		FORWARD_CLIENT_ATTR((s), addr)
 #define FORWARD_NAME(s)		FORWARD_CLIENT_ATTR((s), name)
 #define FORWARD_NAMADDR(s)	FORWARD_CLIENT_ATTR((s), namaddr)
 #define FORWARD_PROTO(s)	FORWARD_CLIENT_ATTR((s), protocol)
 #define FORWARD_HELO(s)		FORWARD_CLIENT_ATTR((s), helo_name)
-
-#define FORWARD_IDENT(s) \
-	(((s)->xforward.flags & SMTPD_STATE_XFORWARD_IDENT) ? \
-	    (s)->queue_id : (s)->ident)
-
-#define FORWARD_DOMAIN(s) \
-	(((s)->xforward.flags & SMTPD_STATE_XFORWARD_DOMAIN) ? \
-	    (s)->xforward.domain : (s)->rewrite_context)
+#define FORWARD_IDENT(s)	FORWARD_IDENT_ATTR(s)
 
 extern void smtpd_xforward_init(SMTPD_STATE *);
 extern void smtpd_xforward_preset(SMTPD_STATE *);
@@ -290,11 +258,4 @@ extern int smtpd_input_transp_mask;
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
-/*
-/*	TLS support originally by:
-/*	Lutz Jaenicke
-/*	BTU Cottbus
-/*	Allgemeine Elektrotechnik
-/*	Universitaetsplatz 3-4
-/*	D-03044 Cottbus, Germany
 /*--*/
