@@ -34,13 +34,6 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
-/*
-/*	TLS support originally by:
-/*	Lutz Jaenicke
-/*	BTU Cottbus
-/*	Allgemeine Elektrotechnik
-/*	Universitaetsplatz 3-4
-/*	D-03044 Cottbus, Germany
 /*--*/
 
 /* System library. */
@@ -102,7 +95,6 @@ void    smtpd_state_init(SMTPD_STATE *state, VSTREAM *stream,
     state->where = SMTPD_AFTER_CONNECT;
     state->recursion = 0;
     state->msg_size = 0;
-    state->act_size = 0;
     state->junk_cmds = 0;
     state->rcpt_overshoot = 0;
     state->defer_if_permit_client = 0;
@@ -122,14 +114,6 @@ void    smtpd_state_init(SMTPD_STATE *state, VSTREAM *stream,
     state->saved_flags = 0;
     state->instance = vstring_alloc(10);
     state->seqno = 0;
-    state->rewrite_context = 0;
-#ifdef USE_TLS
-    state->tls_use_tls = 0;
-    state->tls_enforce_tls = 0;
-    state->tls_auth_only = 0;
-    state->tls_context = 0;
-    state->tls_info = tls_info_zero;
-#endif
 
 #ifdef USE_SASL_AUTH
     if (SMTPD_STAND_ALONE(state))
