@@ -66,13 +66,8 @@
 typedef struct {
     DICT    dict;			/* generic members */
     DBM    *dbm;			/* open database */
-    VSTRING *key_buf;			/* key buffer */
-    VSTRING *val_buf;			/* result buffer */
 } DICT_DBM;
 
-#define SCOPY(buf, data, size) \
-    vstring_str(vstring_strncpy(buf ? buf : (buf = vstring_alloc(10)), data, size))
-
 /* dict_dbm_lookup - find database entry */
 
 static const char *dict_dbm_lookup(DICT *dict, const char *name)
@@ -80,14 +75,9 @@ static const char *dict_dbm_lookup(DICT *dict, const char *name)
     DICT_DBM *dict_dbm = (DICT_DBM *) dict;
     datum   dbm_key;
     datum   dbm_value;
+    static VSTRING *buf;
     const char *result = 0;
 
-    /*
-     * Sanity check.
-     */
-    if ((dict->flags & (DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL)) == 0)
-	msg_panic("dict_dbm_lookup: no DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL flag");
-
     dict_errno = 0;
 
     /*
@@ -107,7 +97,7 @@ static const char *dict_dbm_lookup(DICT *dict, const char *name)
 	dbm_value = dbm_fetch(dict_dbm->dbm, dbm_key);
 	if (dbm_value.dptr != 0) {
 	    dict->flags &= ~DICT_FLAG_TRY0NULL;
-	    result = SCOPY(dict_dbm->val_buf, dbm_value.dptr, dbm_value.dsize);
+	    result = dbm_value.dptr;
 	}
     }
 
@@ -120,8 +110,11 @@ static const char *dict_dbm_lookup(DICT *dict, const char *name)
 	dbm_key.dsize = strlen(name);
 	dbm_value = dbm_fetch(dict_dbm->dbm, dbm_key);
 	if (dbm_value.dptr != 0) {
+	    if (buf == 0)
+		buf = vstring_alloc(10);
+	    vstring_strncpy(buf, dbm_value.dptr, dbm_value.dsize);
 	    dict->flags &= ~DICT_FLAG_TRY1NULL;
-	    result = SCOPY(dict_dbm->val_buf, dbm_value.dptr, dbm_value.dsize);
+	    result = vstring_str(buf);
 	}
     }
 
@@ -144,12 +137,6 @@ static void dict_dbm_update(DICT *dict, const char *name, const char *value)
     datum   dbm_value;
     int     status;
 
-    /*
-     * Sanity check.
-     */
-    if ((dict->flags & (DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL)) == 0)
-	msg_panic("dict_dbm_update: no DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL flag");
-
     dbm_key.dptr = (void *) name;
     dbm_value.dptr = (void *) value;
     dbm_key.dsize = strlen(name);
@@ -213,12 +200,7 @@ static int dict_dbm_delete(DICT *dict, const char *name)
     DICT_DBM *dict_dbm = (DICT_DBM *) dict;
     datum   dbm_key;
     int     status = 1;
-
-    /*
-     * Sanity check.
-     */
-    if ((dict->flags & (DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL)) == 0)
-	msg_panic("dict_dbm_delete: no DICT_FLAG_TRY1NULL | DICT_FLAG_TRY0NULL flag");
+    int     flags = 0;
 
     /*
      * Acquire an exclusive lock.
@@ -280,12 +262,15 @@ static int dict_dbm_sequence(DICT *dict, int function,
     DICT_DBM *dict_dbm = (DICT_DBM *) dict;
     datum   dbm_key;
     datum   dbm_value;
+    int     status = 0;
+    static VSTRING *key_buf;
+    static VSTRING *value_buf;
 
     /*
-     * Acquire a shared lock.
+     * Acquire an exclusive lock.
      */
     if ((dict->flags & DICT_FLAG_LOCK)
-	&& myflock(dict->lock_fd, INTERNAL_LOCK, MYFLOCK_OP_SHARED) < 0)
+	&& myflock(dict->lock_fd, INTERNAL_LOCK, MYFLOCK_OP_EXCLUSIVE) < 0)
 	msg_fatal("%s: lock dictionary: %m", dict_dbm->dict.name);
 
     /*
@@ -302,12 +287,27 @@ static int dict_dbm_sequence(DICT *dict, int function,
 	msg_panic("%s: invalid function: %d", myname, function);
     }
 
+    /*
+     * Release the exclusive lock.
+     */
+    if ((dict->flags & DICT_FLAG_LOCK)
+	&& myflock(dict->lock_fd, INTERNAL_LOCK, MYFLOCK_OP_NONE) < 0)
+	msg_fatal("%s: unlock dictionary: %m", dict_dbm->dict.name);
+
     if (dbm_key.dptr != 0 && dbm_key.dsize > 0) {
 
 	/*
-	 * Copy the key so that it is guaranteed null terminated.
+	 * See if this DB file was written with one null byte appended to key
+	 * an d value or not. If necessary, copy the key.
 	 */
-	*key = SCOPY(dict_dbm->key_buf, dbm_key.dptr, dbm_key.dsize);
+	if (((char *) dbm_key.dptr)[dbm_key.dsize - 1] == 0) {
+	    *key = dbm_key.dptr;
+	} else {
+	    if (key_buf == 0)
+		key_buf = vstring_alloc(10);
+	    vstring_strncpy(key_buf, dbm_key.dptr, dbm_key.dsize);
+	    *key = vstring_str(key_buf);
+	}
 
 	/*
 	 * Fetch the corresponding value.
@@ -317,9 +317,17 @@ static int dict_dbm_sequence(DICT *dict, int function,
 	if (dbm_value.dptr != 0 && dbm_value.dsize > 0) {
 
 	    /*
-	     * Copy the value so that it is guaranteed null terminated.
+	     * See if this DB file was written with one null byte appended to
+	     * key and value or not. If necessary, copy the key.
 	     */
-	    *value = SCOPY(dict_dbm->val_buf, dbm_value.dptr, dbm_value.dsize);
+	    if (((char *) dbm_value.dptr)[dbm_value.dsize - 1] == 0) {
+		*value = dbm_value.dptr;
+	    } else {
+		if (value_buf == 0)
+		    value_buf = vstring_alloc(10);
+		vstring_strncpy(value_buf, dbm_value.dptr, dbm_value.dsize);
+		*value = vstring_str(value_buf);
+	    }
 	} else {
 
 	    /*
@@ -340,14 +348,6 @@ static int dict_dbm_sequence(DICT *dict, int function,
 	    msg_fatal("error seeking %s: %m", dict_dbm->dict.name);
 	return (1);				/* no error: eof/not found */
     }
-
-    /*
-     * Release the shared lock.
-     */
-    if ((dict->flags & DICT_FLAG_LOCK)
-	&& myflock(dict->lock_fd, INTERNAL_LOCK, MYFLOCK_OP_NONE) < 0)
-	msg_fatal("%s: unlock dictionary: %m", dict_dbm->dict.name);
-
     return (0);
 }
 
@@ -358,10 +358,6 @@ static void dict_dbm_close(DICT *dict)
     DICT_DBM *dict_dbm = (DICT_DBM *) dict;
 
     dbm_close(dict_dbm->dbm);
-    if (dict_dbm->key_buf)
-	vstring_free(dict_dbm->key_buf);
-    if (dict_dbm->val_buf)
-	vstring_free(dict_dbm->val_buf);
     dict_free(dict);
 }
 
@@ -432,8 +428,6 @@ DICT   *dict_dbm_open(const char *path, int open_flags, int dict_flags)
     if ((dict_flags & (DICT_FLAG_TRY0NULL | DICT_FLAG_TRY1NULL)) == 0)
 	dict_dbm->dict.flags |= (DICT_FLAG_TRY0NULL | DICT_FLAG_TRY1NULL);
     dict_dbm->dbm = dbm;
-    dict_dbm->key_buf = 0;
-    dict_dbm->val_buf = 0;
 
     if ((dict_flags & DICT_FLAG_LOCK))
 	myfree(dbm_path);
