@@ -24,7 +24,7 @@
   * 4.4BSD and close derivatives.
   */
 #if defined(FREEBSD2) || defined(FREEBSD3) || defined(FREEBSD4) \
-    || defined(FREEBSD5) || defined(FREEBSD6) \
+    || defined(FREEBSD5) \
     || defined(BSDI2) || defined(BSDI3) || defined(BSDI4) \
     || defined(OPENBSD2) || defined(OPENBSD3) \
     || defined(NETBSD1) || defined(NETBSD2) \
@@ -50,7 +50,7 @@
 #endif
 #define GETTIMEOFDAY(t)	gettimeofday(t,(struct timezone *) 0)
 #define ROOT_PATH	"/bin:/usr/bin:/sbin:/usr/sbin"
-#if (defined(__NetBSD_Version__) && __NetBSD_Version__ > 299000900)
+#if (defined(__NetBSD_Version__) && __NetBSD_Version__ > 200040000)
 # define USE_STATVFS
 # define STATVFS_IN_SYS_STATVFS_H
 #else
@@ -66,20 +66,12 @@
 #define NATIVE_DAEMON_DIR "/usr/libexec/postfix"
 #endif
 
-#ifdef BSDI4
-/* #define HAS_IPV6 find out interface lookup method */
-#endif
-
 /* __FreeBSD_version version is major+minor */
 
 #if __FreeBSD_version >= 200000
 #define HAS_DUPLEX_PIPE
 #endif
 
-#if __FreeBSD_version >= 220000
-#define HAS_DEV_URANDOM			/* introduced in 2.1.5 */
-#endif
-
 #if __FreeBSD_version >= 300000
 #define HAS_ISSETUGID
 #endif
@@ -93,7 +85,6 @@
 
 #if OpenBSD >= 200000			/* XXX */
 #define HAS_ISSETUGID
-#define HAS_DEV_URANDOM			/* XXX probably earlier */
 #endif
 
 #if OpenBSD >= 200200			/* XXX */
@@ -110,11 +101,10 @@
 #if __NetBSD_Version__ >= 103000000	/* XXX maybe earlier */
 #undef DEF_MAILBOX_LOCK
 #define DEF_MAILBOX_LOCK "flock, dotlock"
-#define HAS_DEV_URANDOM			/* XXX probably earlier */
 #endif
 
-#if __NetBSD_Version__ >= 105000000
-#define HAS_ISSETUGID			/* XXX maybe earlier */
+#if __NetBSD_Version__ >= 105000000	/* XXX maybe earlier */
+#define HAS_ISSETUGID
 #endif
 
 #if __NetBSD_Version__ >= 106000000	/* XXX maybe earlier */
@@ -122,19 +112,8 @@
 #define SOCKOPT_SIZE	socklen_t
 #endif
 
-#if __NetBSD_Version__ >= 299000900	/* 2.99.9 */
+#if __NetBSD_Version__ >= 200060000	/* 2.0F */
 #define HAS_CLOSEFROM
-#endif
-
-#if (defined(__NetBSD_Version__) && __NetBSD_Version__ >= 105000000) \
-    || (defined(__FreeBSD__) && __FreeBSD__ >= 4) \
-    || (defined(OpenBSD) && OpenBSD >= 200003) \
-    || defined(USAGI_LIBINET6)
-#ifndef NO_IPV6
-# define HAS_IPV6
-# define HAVE_GETIFADDRS
-#endif
-
 #endif
 
  /*
@@ -155,7 +134,6 @@
 #define DEF_DB_TYPE	"hash"
 #define ALIAS_DB_MAP	"hash:/etc/aliases"
 #define GETTIMEOFDAY(t) gettimeofday(t,(struct timezone *) 0)
-#define RESOLVE_H_NEEDS_NAMESER8_COMPAT_H
 #define ROOT_PATH	"/bin:/usr/bin:/sbin:/usr/sbin"
 #define USE_STATFS
 #define STATFS_IN_SYS_MOUNT_H
@@ -164,11 +142,7 @@
 #define PRINTFLIKE(x,y)
 #define SCANFLIKE(x,y)
 #ifndef NO_NETINFO
-# define HAS_NETINFO
-#endif
-#ifndef NO_IPV6
-# define HAS_IPV6
-# define HAVE_GETIFADDRS
+#define HAS_NETINFO
 #endif
 #define NATIVE_SENDMAIL_PATH "/usr/sbin/sendmail"
 #define NATIVE_MAILQ_PATH "/usr/bin/mailq"
@@ -257,11 +231,6 @@ extern int opterr;			/* XXX use <getopt.h> */
 #define STATFS_IN_SYS_MOUNT_H
 #define HAS_POSIX_REGEXP
 #define BROKEN_WRITE_SELECT_ON_NON_BLOCKING_PIPE
-#define NO_MSGHDR_MSG_CONTROL
-#ifndef NO_IPV6
-# define HAS_IPV6
-#endif
-
 #endif
 
  /*
@@ -305,7 +274,6 @@ extern int opterr;
 #define NATIVE_COMMAND_DIR "/usr/etc"
 #define NATIVE_DAEMON_DIR "/usr/libexec/postfix"
 #define STRCASECMP_IN_STRINGS_H
-#define OCTAL_TO_UNSIGNED(res, str) sscanf((str), "%o", &(res))
 #endif
 
  /*
@@ -328,14 +296,12 @@ extern int opterr;
 #define DEF_DB_TYPE	"dbm"
 #define ALIAS_DB_MAP	"dbm:/etc/mail/aliases"
 #define HAS_NIS
-#define HAS_NISPLUS
 #define USE_SYS_SOCKIO_H		/* Solaris 2.5, changed sys/ioctl.h */
 #define GETTIMEOFDAY(t)	gettimeofday(t)
 #define ROOT_PATH	"/bin:/usr/bin:/sbin:/usr/sbin:/usr/ucb"
 #define FIONREAD_IN_SYS_FILIO_H
 #define USE_STATVFS
 #define STATVFS_IN_SYS_STATVFS_H
-#define INT_MAX_IN_LIMITS_H
 #define STREAM_CONNECTIONS		/* avoid UNIX-domain sockets */
 #define LOCAL_LISTEN	stream_listen
 #define LOCAL_ACCEPT	stream_accept
@@ -345,20 +311,6 @@ extern int opterr;
 #define LOCAL_RECV_FD	stream_recv_fd
 #define HAS_VOLATILE_LOCKS
 #define BROKEN_READ_SELECT_ON_TCP_SOCKET
-#define CANT_WRITE_BEFORE_SENDING_FD
-#ifndef NO_POSIX_REGEXP
-# define HAS_POSIX_REGEXP
-#endif
-#ifndef NO_IPV6
-# define HAS_IPV6
-# define HAS_SIOCGLIF
-#endif
-#ifndef NO_CLOSEFROM
-# define HAS_CLOSEFROM
-#endif
-#ifndef NO_DEV_URANDOM
-# define HAS_DEV_URANDOM
-#endif
 
 /*
  * Allow build environment to override paths.
@@ -470,22 +422,6 @@ extern int opterr;
 #define NATIVE_NEWALIAS_PATH "/usr/sbin/newaliases"
 #define NATIVE_COMMAND_DIR "/usr/sbin"
 #define NATIVE_DAEMON_DIR "/usr/libexec/postfix"
-
- /*
-  * XXX Need CMSG_SPACE() and CMSG_LEN() but don't want to drag in everything
-  * that comes with _LINUX_SOURCE_COMPAT.
-  */
-#include <sys/socket.h>
-#ifndef CMSG_SPACE
-#define CMSG_SPACE(len) (_CMSG_ALIGN(sizeof(struct cmsghdr)) + _CMSG_ALIGN(len))
-#endif
-#ifndef CMSG_LEN
-#define CMSG_LEN(len) (_CMSG_ALIGN(sizeof(struct cmsghdr)) + (len))
-#endif
-#ifndef NO_IPV6
-# define HAS_IPV6
-#endif
-#define BROKEN_AI_PASSIVE_NULL_HOST
 #endif
 
 #ifdef AIX4
@@ -526,7 +462,6 @@ extern int initgroups(const char *, int);
 #define NATIVE_COMMAND_DIR "/usr/sbin"
 #define NATIVE_DAEMON_DIR "/usr/libexec/postfix"
 
-#define CANT_USE_SEND_RECV_MSG
 #endif
 
 #ifdef AIX3
@@ -561,7 +496,6 @@ extern int setegid(gid_t);
 extern int initgroups(const char *, int);
 #define NATIVE_SENDMAIL_PATH "/usr/lib/sendmail"
 
-#define CANT_USE_SEND_RECV_MSG
 #endif
 
  /*
@@ -591,7 +525,6 @@ extern int initgroups(const char *, int);
 #define USE_STATVFS
 #define STATVFS_IN_SYS_STATVFS_H
 #define BROKEN_WRITE_SELECT_ON_NON_BLOCKING_PIPE
-#define CANT_USE_SEND_RECV_MSG
 #endif
 
 #if defined(IRIX5)
@@ -599,9 +532,6 @@ extern int initgroups(const char *, int);
 #endif
 
 #if defined(IRIX6)
-#ifndef NO_IPV6
-# define HAS_IPV6
-#endif
 #define HAS_POSIX_REGEXP
 #define PIPES_CANT_FIONREAD
 #endif
@@ -640,11 +570,6 @@ extern int initgroups(const char *, int);
 #define SOCKADDR_SIZE	socklen_t
 #define SOCKOPT_SIZE	socklen_t
 #endif
-#ifndef NO_IPV6
-# define HAS_IPV6
-# define HAS_PROCNET_IFINET6
-# define _PATH_PROCNET_IFINET6 "/proc/net/if_inet6"
-#endif
 #include <linux/version.h>
 #if !defined(KERNEL_VERSION) || (LINUX_VERSION_CODE < KERNEL_VERSION(2,2,0)) \
 	|| (__GLIBC__ < 2)
@@ -653,7 +578,6 @@ extern int initgroups(const char *, int);
 #else
 # define CANT_WRITE_BEFORE_SENDING_FD
 #endif
-#define HAS_DEV_URANDOM			/* introduced in 1.1 */
 #endif
 
 #ifdef LINUX1
@@ -1072,25 +996,6 @@ extern int dup2_pass_on_exec(int oldd, int newd);
 
 #if !defined(USE_STATFS) && !defined(USE_STATVFS)
 #error "define USE_STATFS or USE_STATVFS"
-#endif
-
- /*
-  * Defaults for systems that pre-date IPv6 support.
-  */
-#ifndef HAS_IPV6
-#define EMULATE_IPV4_ADDRINFO
-#define MISSING_INET_PTON
-#define MISSING_INET_NTOP
-extern const char *inet_ntop(int, const void *, char *, size_t);
-extern int inet_pton(int, const char *, void *);
-
-#endif
-
- /*
-  * Defaults for all systems.
-  */
-#ifndef DEF_INET_PROTOCOLS
-#define DEF_INET_PROTOCOLS	"ipv4"
 #endif
 
  /*
@@ -1125,10 +1030,6 @@ extern int inet_pton(int, const char *, void *);
 typedef int WAIT_STATUS_T;
 
 #define NORMAL_EXIT_STATUS(status)	((status) == 0)
-#endif
-
-#ifndef OCTAL_TO_UNSIGNED
-#define OCTAL_TO_UNSIGNED(res, str)	((res) = strtoul((str), (char **) 0, 8))
 #endif
 
  /*
@@ -1221,9 +1122,7 @@ typedef int pid_t;
   * doubles.
   */
 #ifndef ALIGN_TYPE
-# if defined(__hpux) && defined(__ia64)
-# define ALIGN_TYPE	__float80
-# elif defined(__ia64__)
+# ifdef __ia64__
 # define ALIGN_TYPE	long double
 # else
 # define ALIGN_TYPE	double
@@ -1297,24 +1196,6 @@ typedef int pid_t;
   */
 #ifndef SET_H_ERRNO
 #define SET_H_ERRNO(err) (h_errno = (err))
-#endif
-
- /*
-  * Don't mix socket message calls with socket read/write calls. The fact
-  * that you can get away with it only on some stacks implies that there is
-  * no long-term guarantee.
-  */
-#ifndef CAN_WRITE_BEFORE_SENDING_FD
-#define CANT_WRITE_BEFORE_SENDING_FD
-#endif
-
- /*
-  * FreeBSD sendmsg(2) says that after sending a file descriptor, the sender
-  * must not immediately close the descriptor, otherwise it may close the
-  * descriptor before it is actually sent.
-  */
-#ifndef DONT_WAIT_AFTER_SENDING_FD
-#define MUST_READ_AFTER_SENDING_FD
 #endif
 
  /*
